%ifarch %{arm}
%bcond_with bootstrap
%else
%bcond_with bootstrap
%endif

%bcond_without docs

%define sbcl_shell /bin/bash

%ifarch %{ix86}
%define sbcl_arch x86
%endif

%ifarch x86_64
%define sbcl_arch x86-64
%endif

%ifarch %{arm}
%define sbcl_arch arm
%if %{with bootstrap}
%define bootstrap_src -b 11
%define bootstrap_dir sbcl-1.4.11-armhf-linux
%endif
%endif

%ifarch aarch64
%define sbcl_arch arm64
%if %{with bootstrap}
%define bootstrap_src -b 12
%define bootstrap_dir sbcl-1.4.2-arm64-linux
%endif
%endif

Name:           sbcl
Version:        2.0.10
Release:        %mkrel 4
Summary:        Steel Bank Common Lisp compiler and runtime system
License:        Public Domain and MIT and BSD with advertising
Group:          Development/Other
URL:            http://sbcl.sourceforge.net/
Source0:        https://downloads.sourceforge.net/sbcl/sbcl-%{version}-source.tar.bz2
Source1:        https://downloads.sourceforge.net/sbcl/sbcl-%{version}-documentation-html.tar.bz2
#Source11:       https://downloads.sourceforge.net/sbcl/sbcl-1.4.11-armhf-linux-binary.tar.bz2
#Source12:       https://downloads.sourceforge.net/sbcl/sbcl-1.4.2-arm64-linux-binary.tar.bz2
#Patch1:         sbcl-1.4.12-default-sbcl-home.patch
Patch2:         sbcl-1.4.12-personality.patch
#Patch3:         sbcl-1.4.12-optflags.patch
#Patch4:         sbcl-2.0.1-LIB_DIR.patch
#Patch5:         sbcl-1.4.14-gcc10.patch
Patch6:         sbcl-2.0.10-arm.patch

## upstreamable patches
Patch50:        sbcl-2.0.1-generate_version.patch

# Modified from https://bugs.gentoo.org/468482
Patch100:       sbcl-1.4.12-concurrency-test.patch

BuildRequires: gcc
BuildRequires: zlib-devel
# %%check/tests
BuildRequires: ed
BuildRequires: hostname
%if %{with docs}
# doc generation
BuildRequires: ghostscript
BuildRequires: texinfo
BuildRequires: time
%endif
%if %{without bootstrap}
BuildRequires: %{name}
%endif

%description
Steel Bank Common Lisp (SBCL) is a Open Source development environment for
Common Lisp. It includes an integrated native compiler, interpreter, and
debugger.


%prep
%autosetup -p1 %{?bootstrap_src}

# fix permissions (some have eXecute bit set)
find . -name '*.c' | xargs chmod 644

# set version.lisp-expr
sed -i.rpmver -e "s|\"%{version}\"|\"%{version}-%{release}\"|" version.lisp-expr

%build

export CFLAGS="%{optflags}"
export LDFLAGS="%{ldflags}"

export SBCL_HOME=%{_libdir}/%{name}
export DEFAULT_SBCL_HOME=%{_libdir}/%{name}
%{?sbcl_arch:export SBCL_ARCH=%{sbcl_arch}}

%{?sbcl_shell} \
./make.sh \
  --prefix=%{_prefix} \
  --with-sb-core-compression \
  %{?with_bootstrap:--xc-host="$(pwd)/../%{bootstrap_dir}/run-sbcl.sh"} \
  %nil

# docs
%if %{with docs}
make -C doc/manual info

# Handle pre-generated docs
tar xvjf %{SOURCE1}
cp -av %{name}-%{version}/doc/manual/* doc/manual/
%endif

%install
unset SBCL_HOME
export INSTALL_ROOT=%{buildroot}%{_prefix}
export LIB_DIR=%{buildroot}%{_libdir}
%{?sbcl_shell} ./install.sh

# handle docs in files section
rm -rf %{buildroot}%{_docdir}

# 'test-passed' files from %%check
find %{buildroot} -name 'test-passed' | xargs rm -vf

%files
%license COPYING
%doc BUGS CREDITS NEWS
%{_bindir}/*
%dir %{_prefix}/lib/%{name}/
%{_prefix}/lib/%{name}/sbcl.core
%{_prefix}/lib/%{name}/sbcl.mk
%dir %{_prefix}/lib/%{name}/contrib
%{_prefix}/lib/%{name}/contrib/asdf.*
%{_prefix}/lib/%{name}/contrib/sb-aclrepl.*
%{_prefix}/lib/%{name}/contrib/sb-bsd-sockets.*
%{_prefix}/lib/%{name}/contrib/sb-capstone.*
%{_prefix}/lib/%{name}/contrib/sb-cltl2.*
%{_prefix}/lib/%{name}/contrib/sb-concurrency.*
%{_prefix}/lib/%{name}/contrib/sb-cover.*
%{_prefix}/lib/%{name}/contrib/sb-executable.*
%{_prefix}/lib/%{name}/contrib/sb-gmp.*
%{_prefix}/lib/%{name}/contrib/sb-grovel.*
%{_prefix}/lib/%{name}/contrib/sb-introspect.*
%{_prefix}/lib/%{name}/contrib/sb-md5.*
%{_prefix}/lib/%{name}/contrib/sb-mpfr.*
%{_prefix}/lib/%{name}/contrib/sb-posix.*
%{_prefix}/lib/%{name}/contrib/sb-queue.*
%{_prefix}/lib/%{name}/contrib/sb-rotate-byte.*
%{_prefix}/lib/%{name}/contrib/sb-rt.*
%{_prefix}/lib/%{name}/contrib/sb-simple-streams.*
%{_prefix}/lib/%{name}/contrib/sb-sprof.*
%{_prefix}/lib/%{name}/contrib/uiop.*
%{_mandir}/man?/*
%if %{with docs}
%doc doc/manual/sbcl.html
%doc doc/manual/asdf.html
%{_infodir}/asdf.info*
%{_infodir}/sbcl.info*
%endif


%changelog
* Sun Nov 01 2020 joequant <joequant> 2.0.10-4.mga8
+ Revision: 1641156
- revert march fix
- run with armv7 arch

* Sun Nov 01 2020 joequant <joequant> 2.0.10-2.mga8
+ Revision: 1641143
- fix arm build

* Sun Nov 01 2020 joequant <joequant> 2.0.10-1.mga8
+ Revision: 1641138
- update to 2.0.10 and fix build

* Sun Feb 16 2020 wally <wally> 2.0.1-1.mga8
+ Revision: 1533909
- new version 2.0.1

* Fri Feb 14 2020 umeabot <umeabot> 1.4.12-4.mga8
+ Revision: 1519438
- Mageia 8 Mass Rebuild

* Sun Oct 14 2018 wally <wally> 1.4.12-3.mga7
+ Revision: 1320251
- disable bootstrap build on arm

* Sun Oct 14 2018 wally <wally> 1.4.12-2.mga7
+ Revision: 1320246
- disable bootstrap build on aarch64
- bootstrap using static binaries from upstream

* Sun Oct 14 2018 wally <wally> 1.4.12-1.mga7
+ Revision: 1320212
- new version 1.4.12
- enable bootstrap build on arm and aarch64
- sync a bit with Fedora
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Mon Apr 23 2018 kekepower <kekepower> 1.4.6-2.mga7
+ Revision: 1221367
- Non bootstrap build

* Sun Apr 22 2018 kekepower <kekepower> 1.4.6-1.mga7
+ Revision: 1221251
- Update to version 1.4.6
- Rediffed patches

* Fri Oct 21 2016 daviddavid <daviddavid> 1.1.14-5.mga6
+ Revision: 1062892
- disable Postscript and pdf documentation as they fails to build

* Fri Feb 05 2016 umeabot <umeabot> 1.1.14-4.mga6
+ Revision: 938471
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.1.14-3.mga5
+ Revision: 741393
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.1.14-2.mga5
+ Revision: 689043
- Mageia 5 Mass Rebuild

* Tue Jan 21 2014 shlomif <shlomif> 1.1.14-1.mga4
+ Revision: 567357
- Upgraded to 1.1.14.
  The patches were updated in the process.
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Sun Jun 02 2013 kamil <kamil> 1.1.8-1.mga4
+ Revision: 435455
- new version 1.1.8
- drop P10 problem resolved upstream

* Sat Feb 02 2013 kamil <kamil> 1.1.4-1.mga3
+ Revision: 394168
- new version 1.1.4
- add P10 fdr-fix-build-with-new-glibc.patch and fix build

* Sat Dec 01 2012 kamil <kamil> 1.1.2-2.mga3
+ Revision: 324310
- rediff P3
- new version 1.1.2

* Sat Dec 01 2012 kamil <kamil> 1.0.57-2.mga3
+ Revision: 324300
- add new BR: texinfo-tex

* Mon May 28 2012 kamil <kamil> 1.0.57-1.mga3
+ Revision: 247686
- new version 1.0.57

* Fri Jan 13 2012 kamil <kamil> 1.0.55-3.mga2
+ Revision: 195490
- fix license

* Thu Jan 12 2012 kamil <kamil> 1.0.55-2.mga2
+ Revision: 195363
- disable bootstrap building

* Thu Jan 12 2012 kamil <kamil> 1.0.55-1.mga2
+ Revision: 195331
- re-include old patches and rediff them
- drop ppc and sparc patching against %%optflags in optflags.patch
- re-include customize-target-features script
- reeanble and use again old variables:
  o SBCL_HOME
  o DEFAULT_SBCL_HOME
  o RPM_OPT_FLAGS
  o LIB_DIR
- fix scriptlets to install sbcl.info-1 and sbcl.info-2 agains
- install package into old %%{_libdir}/%%{name} place

* Thu Jan 12 2012 kamil <kamil> 1.0.55-0.mga2
+ Revision: 195227
- add missing texlive to BR
- set PREFIX variable (location where the package is working) to %%{_prefix}
- rewrite installation of .info documentation
- new list of files
- drop binary files of sbcl - used previously for bootstrap
- completely rewrite .spec file, inspired by openSUSE one
- make a temporarily initial .spec
  o temporarily disable threating maintance
  o temporarily disable patches
  o make bootstrap with clisp
  o disable post,pre,postup
- new version 1.0.55
- removed %%clean section, %%defattr, cleaning in %%install
+ tv <tv>
- fix bootstrap directory on x86_64
- fix typo in bootstrap macro name on x86_64
- add missing tarballs for bootstrap build
- bootstrap build
- imported package sbcl

